@@ -18,7 +18,8 @@ import types
 import md5
 
 from son import SON
-from son_manipulator import ObjectIdInjector
+from dbref import DBRef
+from son_manipulator import ObjectIdInjector, ObjectIdShuffler
 from collection import Collection
 from errors import InvalidName, CollectionInvalid, OperationFailure
 
@@ -40,9 +41,9 @@ class Database(object):
         Raises TypeError if name is not an instance of (str, unicode). Raises
         InvalidName if name is not a valid database name.
 
-        Arguments:
-        - `connection`: a connection to Mongo
-        - `name`: database name
+        :Parameters:
+          - `connection`: a connection to Mongo
+          - `name`: database name
         """
         if not isinstance(name, types.StringTypes):
             raise TypeError("name must be an instance of (str, unicode)")
@@ -51,7 +52,7 @@ class Database(object):
 
         self.__name = unicode(name)
         self.__connection = connection
-        self.__manipulators = [ObjectIdInjector(self)]
+        self.__manipulators = [ObjectIdInjector(self), ObjectIdShuffler(self)]
 
     def __check_name(self, name):
         for invalid_char in " .$/\\":
@@ -60,10 +61,15 @@ class Database(object):
         if not name:
             raise InvalidName("database name cannot be the empty string")
 
-    def add_son_manipulator(self, manipulator):
+    def add_son_manipulator(self, manipulator, index=-1):
         """Add a new son manipulator to this database.
+
+        :Parameters:
+          - `manipulator`: the manipulator to add
+          - `index` (optional): the index to add the manipulator on the
+            manipulator list
         """
-        self.__manipulators.append(manipulator)
+        self.__manipulators[index:index] = [manipulator]
 
     def connection(self):
         """Get the database connection.
@@ -88,8 +94,8 @@ class Database(object):
 
         Raises InvalidName if an invalid collection name is used.
 
-        Arguments:
-        - `name`: the name of the collection to get
+        :Parameters:
+          - `name`: the name of the collection to get
         """
         return Collection(self, name)
 
@@ -98,8 +104,8 @@ class Database(object):
 
         Raises InvalidName if an invalid collection name is used.
 
-        Arguments:
-        - `name`: the name of the collection to get
+        :Parameters:
+          - `name`: the name of the collection to get
         """
         return self.__getattr__(name)
 
@@ -111,15 +117,16 @@ class Database(object):
         collection already exists.
 
         Options should be a dictionary, with any of the following options:
+
         - "size": desired initial size for the collection. must be less than or
-            equal to 10000000000. for capped collections this size is the max
-            size of the collection.
+          equal to 10000000000. for capped collections this size is the max
+          size of the collection.
         - "capped": if True, this is a capped collection
         - "max": maximum number of objects if capped (optional)
 
-        Arguments:
-        - `name`: the name of the collection to create
-        - `options` (optional): options to use on the new collection
+        :Parameters:
+          - `name`: the name of the collection to create
+          - `options` (optional): options to use on the new collection
         """
         if name in self.collection_names():
             raise CollectionInvalid("collection %s already exists" % name)
@@ -129,9 +136,9 @@ class Database(object):
     def _fix_incoming(self, son, collection):
         """Apply manipulators to an incoming SON object before it gets stored.
 
-        Arguments:
-        - `son`: the son object going into the database
-        - `collection`: the collection the son object is being saved in
+        :Parameters:
+          - `son`: the son object going into the database
+          - `collection`: the collection the son object is being saved in
         """
         for manipulator in self.__manipulators:
             son = manipulator.transform_incoming(son, collection)
@@ -140,9 +147,9 @@ class Database(object):
     def _fix_outgoing(self, son, collection):
         """Apply manipulators to a SON object as it comes out of the database.
 
-        Arguments:
-        - `son`: the son object coming out of the database
-        - `collection`: the collection the son object was saved in
+        :Parameters:
+          - `son`: the son object coming out of the database
+          - `collection`: the collection the son object was saved in
         """
         for manipulator in self.__manipulators:
             son = manipulator.transform_outgoing(son, collection)
@@ -166,8 +173,8 @@ class Database(object):
     def drop_collection(self, name_or_collection):
         """Drop a collection.
 
-        Arguments:
-        - `name_or_collection`: the name of a collection to drop or the
+        :Parameters:
+          - `name_or_collection`: the name of a collection to drop or the
             collection object itself
         """
         name = name_or_collection
@@ -225,8 +232,8 @@ class Database(object):
 
         Raises ValueError if level is not one of (OFF, SLOW_ONLY, ALL).
 
-        Arguments:
-        - `level`: the profiling level to use
+        :Parameters:
+          - `level`: the profiling level to use
         """
         if not isinstance(level, types.IntType) or level < 0 or level > 2:
             raise ValueError("level must be one of (OFF, SLOW_ONLY, ALL)")
@@ -298,9 +305,9 @@ class Database(object):
         to *all* databases. Effectively, "admin" access means root access to the
         database.
 
-        Arguments:
-        - `name`: the name of the user to authenticate
-        - `password`: the password of the user to authenticate
+        :Parameters:
+          - `name`: the name of the user to authenticate
+          - `password`: the password of the user to authenticate
         """
         if not isinstance(name, types.StringTypes):
             raise TypeError("name must be an instance of (str, unicode)")
@@ -329,3 +336,16 @@ class Database(object):
         result = self._command({"logout": 1})
         if result["ok"] != 1:
             raise OperationFailure("logout failed: %s" % result["errmsg"])
+
+    def dereference(self, dbref):
+        """Dereference a DBRef, getting the SON object it points to.
+
+        Raises TypeError if dbref is not an instance of DBRef. Returns a SON
+        object or None if the reference does not point to a valid object.
+
+        :Parameters:
+          - `dbref`: the reference
+        """
+        if not isinstance(dbref, DBRef):
+            raise TypeError("cannot dereference a %s" % type(dbref))
+        return self[dbref.collection()].find_one(dbref.id())
