@@ -18,6 +18,7 @@ New manipulators should be defined as subclasses of SONManipulator and can be
 installed on a database by calling `pymongo.database.Database.add_son_manipulator`."""
 
 from objectid import ObjectId
+from son import SON
 
 class SONManipulator(object):
     """A base son manipulator.
@@ -27,26 +28,26 @@ class SONManipulator(object):
     def __init__(self, database):
         """Instantiate the manager.
 
-        Arguments:
-        - `database`: a Mongo Database
+        :Parameters:
+          - `database`: a Mongo Database
         """
         self.__database = database
 
     def transform_incoming(self, son, collection):
         """Manipulate an incoming son object.
 
-        Arguments:
-        - `son`: the son object to be inserted into the database
-        - `collection`: the collection the object is being inserted into
+        :Parameters:
+          - `son`: the son object to be inserted into the database
+          - `collection`: the collection the object is being inserted into
         """
         return son
 
     def transform_outgoing(self, son, collection):
         """Manipulate an outgoing son object.
 
-        Arguments:
-        - `son`: the son object being retrieved from the database
-        - `collection`: the collection this object was stored in
+        :Parameters:
+          - `son`: the son object being retrieved from the database
+          - `collection`: the collection this object was stored in
         """
         return son
 
@@ -60,6 +61,18 @@ class ObjectIdInjector(SONManipulator):
             son["_id"] = ObjectId()
         return son
 
+class ObjectIdShuffler(SONManipulator):
+    """A son manipulator that moves _id to the first position.
+    """
+    def transform_incoming(self, son, collection):
+        """Move _id to the front if it's there.
+        """
+        if not "_id" in son:
+            return son
+        transformed = SON({"_id": son["_id"]})
+        transformed.update(son)
+        return transformed
+
 class NamespaceInjector(SONManipulator):
     """A son manipulator that adds the _ns field.
     """
